#
# spec file for package perl-Try-Tiny
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Try-Tiny
Version:        0.19
Release:        1.2
%define cpan_name Try-Tiny
Summary:        Minimal try/catch with proper preservation of $@
License:        MIT
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Try-Tiny/
Source:         http://www.cpan.org/authors/id/D/DO/DOY/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
%{perl_requires}

%description
This module provides bare bones 'try'/'catch'/'finally' statements that are
designed to minimize common mistakes with eval blocks, and NOTHING else.

This is unlike the TryCatch manpage which provides a nice syntax and avoids
adding another call stack layer, and supports calling 'return' from the
'try' block to return from the parent subroutine. These extra features come
at a cost of a few dependencies, namely the Devel::Declare manpage and the
Scope::Upper manpage which are occasionally problematic, and the additional
catch filtering uses the Moose manpage type constraints which may not be
desirable either.

The main focus of this module is to provide simple and reliable error
handling for those having a hard time installing the TryCatch manpage, but
who still want to write correct 'eval' blocks without 5 lines of
boilerplate each time.

It's designed to work as correctly as possible in light of the various
pathological edge cases (see the /BACKGROUND manpage) and to be compatible
with any style of error values (simple strings, references, objects,
overloaded objects, etc).

If the 'try' block dies, it returns the value of the last statement
executed in the 'catch' block, if there is one. Otherwise, it returns
'undef' in scalar context or the empty list in list context. The following
examples all assign '"bar"' to '$x':

  my $x = try { die "foo" } catch { "bar" };
  my $x = try { die "foo" } || { "bar" };
  my $x = (try { die "foo" }) // { "bar" };

  my $x = eval { die "foo" } || "bar";

You can add 'finally' blocks, yielding the following:

  my $x;
  try { die 'foo' } finally { $x = 'bar' };
  try { die 'foo' } catch { warn "Got a die: $_" } finally { $x = 'bar' };

'finally' blocks are always executed making them suitable for cleanup code
which cannot be handled using local. You can add as many 'finally' blocks
to a given 'try' block as you like.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes LICENSE maint README

%changelog
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.19
  - fix an obscure issue with loading modules during global destruction
    (ilmari, #11)
  - documentation updates (anaxagoras, #12)
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.18
  - fix tests for pre-Test-More-0.88 (Paul Howarth, #10)
  - work around [rt.perl #119311] which was causing incorrect error messages in
    some cases during global destruction (Graham Knop, #9)
* Sat Jul 27 2013 coolo@suse.com
- updated to 0.16
  - remove accidental Sub::Name test dep
  - optionally use Sub::Name to name the try/catch/finally blocks, if available
    (Mark Fowler)
  - also throw an exception for catch/finally in scalar context (RT#81070)
  - fix tests failing on 5.6.x due to differing DESTROY semantics
  - excise superfluous local($@) call - 7%% speedup
  - fix (fsvo) broken URLs (RT#55659)
  - proper exception on erroneous usage of bare catch/finally (RT#81070)
  - proper exception on erroneous use of multiple catch{} blocks
  - clarify exception occuring on unterminated try block (RT#75712)
  - fix the prototypes shown in docs to match code (RT#79590; thanks, Pushtaev
    Vadim)
  - warn loudly on exceptions in finally() blocks
  - dzilify
* Tue Jun 11 2013 coolo@suse.com
- rebuild for perl 5.18
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.12
  - doc fixes
* Mon Sep 19 2011 coolo@suse.com
- updated to 0.11
  - fix broken dist
  - clarify some docs
* Tue May 17 2011 coolo@opensuse.org
- updated to 0.09
  - don't index Try::Tiny::ScopeGuard
  - fix require vs use issue in blead (RT63410)
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 11 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fixed deps
  o fix License
- noarch pkg
* Mon Nov  1 2010 pascal.bleser@opensuse.org
- update to 0.07:
  * allow multiple finally blocks
  * pass the error, if any, to finally blocks when called
- changes from 0.05:
  * documentation fixes and clarifications
* Mon Jan 25 2010 lars@linux-schulserver.de
- update to 0.04:
  + Restore list context propagation for catch blocks
  + Fix a bug where finally blocks weren't always invoked
  + More documentation and tests (many people)
  + Sets $@ to the previous value at the beginning of the eval, to
    allow the capture of an error stack when calling die.
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 0.02
